@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (C) 2008 by BogDan Vatra                                    *
  *   bogdan@licentia.eu                                                    *
- *   Copyright (C) 2010-2022 Robin Stuart                                  *
+ *   Copyright (C) 2010-2023 Robin Stuart                                  *
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -124,11 +124,19 @@ public:
     void setStructApp(const int count, const int index, const QString& id);
     void clearStructApp();
 
-    /* Foreground colour */
+    /* Foreground colour (may be RGB(A) hex string or CMYK decimal "C,M,Y,K" percentage string) */
+    QString fgStr() const; // `symbol->fgcolour`
+    bool setFgStr(const QString& fgStr); // Returns false if not valid colour string
+
+    /* Foreground colour as QColor */
     QColor fgColor() const; // `symbol->fgcolour`
     void setFgColor(const QColor& fgColor);
 
-    /* Background colour */
+    /* Background colour (may be RGB(A) hex string or CMYK decimal "C,M,Y,K" percentage string) */
+    QString bgStr() const; // `symbol->bgcolour`
+    bool setBgStr(const QString& bgStr); // Returns false if not valid colour string
+
+    /* Background colour as QColor */
     QColor bgColor() const; // `symbol->bgcolour`
     void setBgColor(const QColor& bgColor);
 
@@ -157,7 +165,11 @@ public:
     void setFontSetting(int fontSettingIndex); // Sets from comboBox index
     void setFontSettingValue(int fontSetting); // Sets literal value
 
-    /* Show (true) or hide (false) Human Readable Text */
+    /* Text gap */
+    float textGap() const; // `symbol->text_gap`
+    void setTextGap(float textGap);
+
+    /* Show (true) or hide (false) Human Readable Text (HRT) */
     bool showText() const; // `symbol->show_hrt`
     void setShowText(bool showText);
 
@@ -200,6 +212,14 @@ public:
     bool readerInit() const; // `symbol->output_options | READER_INIT`
     void setReaderInit(bool readerInit);
 
+    /* Whether to add quiet zone indicators ("<", ">") to HRT (EAN/UPC) */
+    bool guardWhitespace() const; // `symbol->output_options | EANUPC_GUARD_WHITESPACE`
+    void setGuardWhitespace(bool guardWhitespace);
+
+    /* Whether to embed the font in vector output - currently only for SVG output of EAN/UPC */
+    bool embedVectorFont() const; // `symbol->output_options | EANUPC_GUARD_WHITESPACE`
+    void setEmbedVectorFont(bool embedVectorFont);
+
     /* Affects error/warning value returned by Zint API (see `getError()` below) */
     int warnLevel() const; // `symbol->warn_level`
     void setWarnLevel(int warnLevel);
@@ -232,7 +252,8 @@ public:
     /* Test capabilities - `ZBarcode_Cap()` */
     bool hasHRT(int symbology = 0) const;
     bool isStackable(int symbology = 0) const;
-    bool isExtendable(int symbology = 0) const;
+    bool isEANUPC(int symbology = 0) const;
+    bool isExtendable(int symbology = 0) const; /* Legacy - same as `isEANUPC()` */
     bool isComposite(int symbology = 0) const;
     bool supportsECI(int symbology = 0) const;
     bool supportsGS1(int symbology = 0) const;
@@ -322,7 +343,6 @@ private:
     static void arg_str(QString& cmd, const char *const opt, const QString& val);
     static void arg_int(QString& cmd, const char *const opt, const int val, const bool allowZero = false);
     static void arg_bool(QString& cmd, const char *const opt, const bool val);
-    static void arg_color(QString& cmd, const char *const opt, const QColor val);
     static void arg_data(QString& cmd, const char *const opt, const QString& val, const bool win);
     static void arg_seg(QString& cmd, const int seg_no, const QZintSeg& val, const bool win);
     static void arg_data_esc(QString& cmd, const char *const opt, QString& text, const bool win);
@@ -348,9 +368,10 @@ private:
     bool m_dotty;
     float m_dot_size;
     float m_guardDescent;
+    float m_textGap;
     struct zint_structapp m_structapp;
-    QColor m_fgColor;
-    QColor m_bgColor;
+    QString m_fgStr;
+    QString m_bgStr;
     bool m_cmyk;
     int m_borderType;
     int m_borderWidth;
@@ -367,6 +388,8 @@ private:
     bool m_gs1parens;
     bool m_gs1nocheck;
     bool m_reader_init;
+    bool m_guard_whitespace;
+    bool m_embed_vector_font;
     int m_warn_level;
     bool m_debug;
     int m_encodedWidth;
